@@ -19,57 +19,32 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
+#include <asm/sizes.h> 
 
 #ifndef __ASM_ARCH_REGMAP_H
 #define __ASM_ARCH_REGMAP_H
 
-/*
- * Here's the rules:
- * - EP93xx register addresses in regmap.h are physical addresses.
- *
- * - IO_ADDRESS translates a physical address to a virtual one for the
- *   EP93xx's register space only.  Don't use it for actual memory.
- *
- * - The regs_*.h files in include/asm-arm/arch-ep93xx use IO_ADDRESS to
- *   translate physical register addresses to virtual addresses.
- *
- * - If you do i/o using any of the i/o macros in include/asm-arm/io.h
- *   then supply a physical address as these use __io which is the same
- *   as IO_ADDRESS
- *
- */ 
-
-
 /*
  * Where in virtual memory the IO devices (timers, system controllers
  * and so on).  This gets used in arch/arm/mach-ep93xx/mm.c.
- *
- *  Note: IO is 1-1 mapping, but use IO_VIRT() on all IO addresses
- *  so that it can be moved in the future.
  */
-#define IO_BASE_VIRT        0xE0000000     // Virtual address of IO 
+#define IO_BASE_VIRT        0xFF000000     // Virtual address of IO 
 #define IO_BASE_PHYS        0x80000000     // Physical address of IO
-#define IO_SIZE             0x0A000000     // How much?
+#define IO_SIZE             0x00A00000     // How much?
 
-#define PCMCIA_BASE_VIRT    0xD0000000     // Virtual address of PCMCIA 
-#define PCMCIA_BASE_PHYS    0xA0000000     // Physical address of PCMCIA
+/*
+ * We don't map the PCMCIA initially.  The PCMCIA driver will use ioremap
+ * to be able to see it.  But besides that PCMCIA will not exist in the
+ * memory map.
+ */
+#define PCMCIA_BASE_VIRT    0xD0000000     // Virtual address of PCMCIA
+#define PCMCIA_BASE_PHYS    0x40000000     // Physical address of PCMCIA
 #define PCMCIA_SIZE         0x10000000     // How much?
 
 /*
- * The HW_REG macro assumes that the param is a virtual address
+ * The memory maps and register lists below show physical addresses, while the
+ * corresponding #defines use virtual addresses.
  */
-#define HW_REG(reg) ((unsigned int volatile *)reg)
-
-/* 
- * (Translates a physical address to a virtual address)
- * First cast the pa to an unsigned int in case we are using this
- * on a macro that is already cast as a pointer.
- */
-#ifdef __ASSEMBLY__
-#define IO_ADDRESS(pa) (pa - IO_BASE_PHYS + IO_BASE_VIRT) 
-#else
-#define IO_ADDRESS(pa) (((unsigned int)pa) - IO_BASE_PHYS + IO_BASE_VIRT) 
-#endif
 
 /******************************************************************/
 /*         EP93xx Memory Map and Register list                    */
@@ -84,8 +59,6 @@
 /* A000_0000 - Afff_ffff: PCMCIA Memory, I/O, and Attribute space */
 /* B000_0000 - ffff_ffff: External SRAM memory                    */
 
-
-
 /******************************************************************/
 /*           EP93xx AHB Blocks Base Address                       */
 /******************************************************************/
@@ -106,7 +79,7 @@
 /* 800B_0000 800B_FFFF: 64 K VIC1 control registers               */
 /* 800C_0000 800C_FFFF: 64 K VIC2 control registers               */
 /* TAG: literal */
-#define EP93XX_AHB_BASE (IO_BASE_PHYS)
+#define EP93XX_AHB_BASE (IO_BASE_VIRT)
 
 /* ARM920T Address Description                             */
 /*                                                         */
@@ -172,9 +145,6 @@
 /* * Write this location once to clear the bit (see        */
 /* Interrupt/Status register description for which bits    */
 /* this rule applies to).                                  */
-/*---------------------------------------------------------*/
-/* Changed to start at offset 0 from base of AHB Space     */
-/*                                                     clc */
 
 /* 8000_0000 - 8000_ffff: DMA  */
 #define DMA_OFFSET              0x000000
@@ -447,7 +417,7 @@
 #define MAC_CFG_REG2            (MAC_BASE+0x108) /*   */
 
 
-/* 8002_0000 - 8002_ffff: USH */
+/* 8002_0000 - 8002_ffff: USB */
 #define USB_OFFSET              0x020000
 #define USB_BASE                (EP93XX_AHB_BASE|USB_OFFSET)
 #define HCREVISION              (USB_BASE+0x00)
@@ -566,29 +536,22 @@
 /* 8004_0000 - 8004_ffff: Graphics */
 #define GRAPHICS_OFFSET         0x040000
 #define GRAPHICS_BASE           (EP93XX_AHB_BASE|GRAPHICS_OFFSET)
-///#define SRCPIXELSTRT            (GRAPHICS_BASE+0x00)
-///#define DESTPIXELSTRT           (GRAPHICS_BASE+0x04)
-///#define BLKSRCSTRT              (GRAPHICS_BASE+0x08)
-///#define BLKDSTSTRT              (GRAPHICS_BASE+0x0C)
-///#define BLKSRCWIDTH             (GRAPHICS_BASE+0x10)
-///#define SRCLINELENGTH           (GRAPHICS_BASE+0x14)
-///#define BLKDESTWIDTH            (GRAPHICS_BASE+0x18)
-///#define BLKDESTHEIGHT           (GRAPHICS_BASE+0x1C)
-///#define DESTLINELENGTH          (GRAPHICS_BASE+0x20)
-///#define BLOCKCTRL               (GRAPHICS_BASE+0x24)
-///#define TRANSPATTRN             (GRAPHICS_BASE+0x28)
-///#define BLOCKMASK               (GRAPHICS_BASE+0x2C)
-///#define BACKGROUND              (GRAPHICS_BASE+0x30)
-///#define LINEINC                 (GRAPHICS_BASE+0x34)
-///#define LINEINIT                (GRAPHICS_BASE+0x38)
-///#define LINEPATTRN              (GRAPHICS_BASE+0x3C)
-///#define GOATTCR                 (GRAPHICS_BASE+0x40)
-///#define GOATTISRA               (GRAPHICS_BASE+0x44)
-///#define GOATTISRB               (GRAPHICS_BASE+0x48)
-///#define GOATTOCRA               (GRAPHICS_BASE+0x4C)
-///#define GOATTOCRB               (GRAPHICS_BASE+0x50)
-///#define GOATTOCRC               (GRAPHICS_BASE+0x54) 
-///#define GOATTCER                (GRAPHICS_BASE+0x80)
+#define SRCPIXELSTRT            (GRAPHICS_BASE+0x00)
+#define DESTPIXELSTRT           (GRAPHICS_BASE+0x04)
+#define BLKSRCSTRT              (GRAPHICS_BASE+0x08)
+#define BLKDSTSTRT              (GRAPHICS_BASE+0x0C)
+#define BLKSRCWIDTH             (GRAPHICS_BASE+0x10)
+#define SRCLINELENGTH           (GRAPHICS_BASE+0x14)
+#define BLKDESTWIDTH            (GRAPHICS_BASE+0x18)
+#define BLKDESTHEIGHT           (GRAPHICS_BASE+0x1C)
+#define DESTLINELENGTH          (GRAPHICS_BASE+0x20)
+#define BLOCKCTRL               (GRAPHICS_BASE+0x24)
+#define TRANSPATTRN             (GRAPHICS_BASE+0x28)
+#define BLOCKMASK               (GRAPHICS_BASE+0x2C)
+#define BACKGROUND              (GRAPHICS_BASE+0x30)
+#define LINEINC                 (GRAPHICS_BASE+0x34)
+#define LINEINIT                (GRAPHICS_BASE+0x38)
+#define LINEPATTRN              (GRAPHICS_BASE+0x3C)
 
 
 
@@ -621,19 +584,19 @@
 /* 0x8000.2004 SMCBCR1(Bank config register 1) SMCBCR1(Bank config register 1) */
 /* 0x8000.2008 SMCBCR2(Bank config register 2) SMCBCR2(Bank config register 2) */
 /* 0x8000.200C SMCBCR3(Bank config register 3) SMCBCR3(Bank config register 3) */
-/* 0x8000.2010 Reserved, RAZ Reserved, RAZ                                     */
-/* 0x8000.2014 Reserved, RAZ Reserved, RAZ                                     */
+/* 0x8000.2010 Reserved, RAZ                   Reserved, RAZ                   */
+/* 0x8000.2014 Reserved, RAZ                   Reserved, RAZ                   */
 /* 0x8000.2018 SMCBCR6(Bank config register 6) SMCBCR6(Bank config register 6) */
 /* 0x8000.201C SMCBCR7(Bank config register 7) SMCBCR7(Bank config register 7) */
-/* 0x8000.2020 PC1Attribute Register PC1Attribute                              */
-/* 0x8000.2024 PC1Common Register PC1Common                                    */
-/* 0x8000.2028 PC1IO Register PC1IO                                            */
-/* 0x8000.202C Reserved, RAZ Reserved, RAZ                                     */
-/* 0x8000.2030 PC2Attribute Register PC2Attribute                              */
-/* 0x8000.2034 PC2Common Register PC2Common                                    */
-/* 0x8000.2038 PC2IO Register PC2IO                                            */
-/* 0x8000.203C Reserved, RAZ Reserved, RAZ                                     */
-/* 0x8000.2040 PCMCIA control register PCMCIA control register                 */
+/* 0x8000.2020 PCAttribute Register            PCAttribute Register            */
+/* 0x8000.2024 PCCommon Register               PCCommon Register               */
+/* 0x8000.2028 PCIO Register                   PCIO Register                   */
+/* 0x8000.202C Reserved, RAZ                   Reserved, RAZ                   */
+/* 0x8000.2030 Reserved, RAZ                   Reserved, RAZ                   */
+/* 0x8000.2034 Reserved, RAZ                   Reserved, RAZ                   */
+/* 0x8000.2038 Reserved, RAZ                   Reserved, RAZ                   */
+/* 0x8000.203C Reserved, RAZ                   Reserved, RAZ                   */
+/* 0x8000.2040 PCMCIACtrl Register             PCMCIACtrl Register             */
 
 #define SRAM_OFFSET             0x080000
 #define SRAM_BASE               (EP93XX_AHB_BASE|SRAM_OFFSET)
@@ -641,19 +604,20 @@
 #define SMCBCR1                 (SRAM_BASE+0x04) /* 0x8000.2004  Bank config register 1 */
 #define SMCBCR2                 (SRAM_BASE+0x08) /* 0x8000.2008  Bank config register 2 */
 #define SMCBCR3                 (SRAM_BASE+0x0C) /* 0x8000.200C  Bank config register 3 */
-                                                                  /* 0x8000.2010  Reserved, RAZ          */
-                                                                  /* 0x8000.2014  Reserved, RAZ          */
+                                                 /* 0x8000.2010  Reserved, RAZ          */
+                                                 /* 0x8000.2014  Reserved, RAZ          */
 #define SMCBCR6                 (SRAM_BASE+0x18) /* 0x8000.2018  Bank config register 6 */
 #define SMCBCR7                 (SRAM_BASE+0x1C) /* 0x8000.201C  Bank config register 7 */
-#define PC1ATTRIB               (SRAM_BASE+0x20) /* 0x8000.2020  PC1 Attribute Register */
-#define PC1COMMON               (SRAM_BASE+0x24) /* 0x8000.2024  PC1 Common Register    */
-#define PC1IO                   (SRAM_BASE+0x28) /* 0x8000.2028  PC1 IO Register        */
-                                                                  /* 0x8000.202C Reserved, RAZ           */
-#define PC2ATTRIB               (SRAM_BASE+0x30) /* 0x8000.2030 PC2 Attribute Register   */
-#define PC2COMMON               (SRAM_BASE+0x34) /* 0x8000.2034 PC2 Common Register     */
-#define PC2IO                   (SRAM_BASE+0x38) /* 0x8000.2038 PC2 IO Register         */
-                                                                  /* 0x8000.203C Reserved, RAZ           */
-#define PCMCIACNT               (SRAM_BASE+0x40) /* 0x8000.2040 PCMCIA control register */
+
+#define SMC_PCAttribute         (SRAM_BASE+0x20) /* 0x8000.2020  PCMCIA Attribute Register */
+#define SMC_PCCommon            (SRAM_BASE+0x24) /* 0x8000.2024  PCMCIA Common Register    */
+#define SMC_PCIO                (SRAM_BASE+0x28) /* 0x8000.2028  PCMCIA IO Register        */
+                                                 /* 0x8000.202C  Reserved, RAZ           */
+											   	 /* 0x8000.2030  Reserved, RAZ           */
+												 /* 0x8000.2034  Reserved, RAZ           */
+												 /* 0x8000.2038  Reserved, RAZ           */
+                                                 /* 0x8000.203C  Reserved, RAZ           */
+#define SMC_PCMCIACtrl          (SRAM_BASE+0x40) /* 0x8000.2040  PCMCIA control register */
 
 
 /* 8009_0000 - 8009_ffff: Boot ROM (Remap low or high) */
@@ -667,20 +631,20 @@
 /* 800A_0000 - 800A_ffff: IDE Interface  */
 #define IDE_OFFSET              0x0a0000
 #define IDE_BASE                (EP93XX_AHB_BASE|IDE_OFFSET)
-///#define IDECR                   (IDE_BASE+0x00)
-///#define IDECFG                  (IDE_BASE+0x04)
-///#define IDEMDMAOP               (IDE_BASE+0x08)
-///#define IDEUDMAOP               (IDE_BASE+0x0C)
-///#define IDEDATAOUT              (IDE_BASE+0x10)
-///#define IDEDATAIN               (IDE_BASE+0x14)
-///#define IDEMDMADATAOUT          (IDE_BASE+0x18)
-///#define IDEMDMADATAIN           (IDE_BASE+0x1C)
-///#define IDEUDMADATAOUT          (IDE_BASE+0x20)
-///#define IDEUDMADATAIN           (IDE_BASE+0x24)
-///#define IDEUDMASTATUS           (IDE_BASE+0x28)
-///#define IDEUDMADEBUG            (IDE_BASE+0x2C)
-///#define IDEUDMAWFST             (IDE_BASE+0x30)
-///#define IDEUDMARFST             (IDE_BASE+0x34)
+#define IDECR                   (IDE_BASE+0x00)
+#define IDECFG                  (IDE_BASE+0x04)
+#define IDEMDMAOP               (IDE_BASE+0x08)
+#define IDEUDMAOP               (IDE_BASE+0x0C)
+#define IDEDATAOUT              (IDE_BASE+0x10)
+#define IDEDATAIN               (IDE_BASE+0x14)
+#define IDEMDMADATAOUT          (IDE_BASE+0x18)
+#define IDEMDMADATAIN           (IDE_BASE+0x1C)
+#define IDEUDMADATAOUT          (IDE_BASE+0x20)
+#define IDEUDMADATAIN           (IDE_BASE+0x24)
+#define IDEUDMASTATUS           (IDE_BASE+0x28)
+#define IDEUDMADEBUG            (IDE_BASE+0x2C)
+#define IDEUDMAWFST             (IDE_BASE+0x30)
+#define IDEUDMARFST             (IDE_BASE+0x34)
 
 
 
@@ -832,7 +796,7 @@
 /* 8095_0000 8FFF_FFFF: 128M Reserved                             */
 
 
-#define EP93XX_APB_BASE (IO_BASE_PHYS | 0x00800000)
+#define EP93XX_APB_BASE (IO_BASE_VIRT | 0x00800000)
 
 
 /* 8080_0000 - 8080_ffff: Reserved  */
@@ -1003,12 +967,12 @@
 #define GPIO_PHDR                (GPIO_BASE+0x40)
 #define GPIO_PHDDR               (GPIO_BASE+0x44)
 // #define 0x8084.0048 RAZ RAZ                            
-#define GPIO_INTTYPE1            (GPIO_BASE+0x4C)
-#define GPIO_INTTYPE2            (GPIO_BASE+0x50)
+#define GPIO_FINTTYPE1           (GPIO_BASE+0x4C)
+#define GPIO_FINTTYPE2           (GPIO_BASE+0x50)
 #define GPIO_FEOI                (GPIO_BASE+0x54) /* WRITE ONLY - READ UNDEFINED */
-#define GPIO_INTEN               (GPIO_BASE+0x58)
-#define GPIO_INTSTATUS           (GPIO_BASE+0x5C)
-#define GPIO_RAWINTSTASUS        (GPIO_BASE+0x60) 
+#define GPIO_FINTEN              (GPIO_BASE+0x58)
+#define GPIO_INTSTATUSF          (GPIO_BASE+0x5C)
+#define GPIO_RAWINTSTASUSF       (GPIO_BASE+0x60) 
 #define GPIO_FDB                 (GPIO_BASE+0x64)
 #define GPIO_PAPINDR             (GPIO_BASE+0x68)
 #define GPIO_PBPINDR             (GPIO_BASE+0x6C)
